@@ -23,7 +23,7 @@ sub auto {
         $class->load($backend, @args);
     } catch {
         warn "Autoloading '$backend' backend failed. Falling back to the Standalone. ",
-            "(You might need to install Plack::Handler::$backend from CPAN)\n"
+            "(You might need to install Plack::Handler::$backend from CPAN.  Caught error was: $_)\n"
                 if $ENV{PLACK_DEV} && $ENV{PLACK_DEV} eq 'development';
         $class->load('Standalone' => @args);
     };
