@@ -95,6 +95,25 @@ Realm name to display in the basic authentication dialog. Defaults to I<restrict
 
 =back
 
+=head1 LIMITATIONS
+
+This middleware expects that the application has a full access to the
+headers sent by clients in PSGI environment. That is normally the case
+with standalone Perl PSGI web servers such as L<Starman> or
+L<HTTP::Server::Simple::PSGI>.
+
+However, in a web server configuration where you can't achieve this
+(i.e. using your application via mod_perl, CGI or FastCGI), this
+middleware does not work since your application can't know the value
+of C<Authorization:> header.
+
+If you use Apache as a web server and CGI or mod_perl to run your PSGI
+application, you can use mod_rewrite to pass the Authorization header
+to the application with the rewrite rule like following.
+
+  RewriteEngine on
+  RewriteRule .* - [E=HTTP_AUTHORIZATION:%{HTTP:Authorization},L]
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
