@@ -116,13 +116,21 @@ sub validate_res {
         $croak->('body should be an array ref or filehandle');
     }
 
-    if (ref $res->[2] eq 'ARRAY' && grep utf8::is_utf8($_), @{$res->[2]}) {
+    if (ref $res->[2] eq 'ARRAY' && grep _is_really_utf8($_), @{$res->[2]}) {
         $croak->('body must be bytes and should not contain wide characters (UTF-8 strings).');
     }
 
     return $res;
 }
 
+# NOTE: Some modules like HTML:: or XML:: could possibly generate
+# ASCII only strings with utf8 flags on. They're actually safe to
+# print, so there's no need to give warnings about it.
+sub _is_really_utf8 {
+    my $str = shift;
+    utf8::is_utf8($str) && $str =~ /[^\x00-\x7f]/;
+}
+
 1;
 __END__
 
